@@ -288,7 +288,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
     print("-" * 10)
     print('Estimating Resolution Function')
     print("-" * 10)
-    refl.resolution_function(the_boss.data_source.experiment.measuremnt.qz_dimension,
+    refl.resolution_function(the_boss.data_source.experiment.measurement.qz_dimension,
                              progress=True)
     the_boss.reduction.data_state.resolution = 'estimated'
 
